<?php
/*
Plugin Name: WooCommerce Rename First Tab
Description: Rename the first WooCommerce product tab (Description) to either product title, most used word, or keep it as description.
Version: 1.0
Author: EasyToolsWP.com
*/

// Tilføj indstilling til WooCommerce produktindstillinger
add_filter( 'woocommerce_product_settings', 'custom_rename_tab_settings' );

function custom_rename_tab_settings( $settings ) {
    $settings[] = array(
        'name'     => 'Select First Tab Name',
        'id'       => 'first_tab_name',
        'type'     => 'select',
        'options'  => array(
            'description' => 'Description (Standard)',
            'title'       => 'Product Title',
            'most_used'   => 'Most Used Word'
        ),
        'desc'     => 'Choose what the first tab should be named.',
        'default'  => 'description',
        'autoload' => false,
    );
    return $settings;
}

// Ændrer fanenavnet baseret på brugerens valg
add_filter( 'woocommerce_product_tabs', 'custom_rename_description_tab', 98 );

function custom_rename_description_tab( $tabs ) {
    // Hent valgt indstilling
    $selected_tab_name = get_option( 'first_tab_name', 'description' );
    
    // Hent produktets titel
    global $product;
    $product_title = $product->get_title();
    
    // Hent produktbeskrivelsen
    $description = $product->get_description();
    
    // Find det mest brugte ord i beskrivelsen
    $most_used_word = get_most_used_word( $description );
    
    // Logik for at ændre navnet på fanen
    if ( isset( $tabs['description'] ) ) {
        if ( $selected_tab_name === 'title' ) {
            $tabs['description']['title'] = $product_title;
        } elseif ( $selected_tab_name === 'most_used' && $most_used_word ) {
            $tabs['description']['title'] = $most_used_word;
        } else {
            $tabs['description']['title'] = __( 'Description', 'woocommerce' );
        }
    }

    return $tabs;
}

// Funktion til at finde det mest brugte ord i teksten
function get_most_used_word( $text ) {
    // Fjern tegnsætning og gør teksten til små bogstaver
    $text = strtolower( preg_replace( '/[^\w\s]/', '', $text ) );
    $words = explode( ' ', $text );

    // Tæl forekomster af ord
    $word_counts = array_count_values( $words );

    // Find det mest brugte ord
    arsort( $word_counts );
    return key( $word_counts );
}
?>
